# Wownero

Container images for the official Wownero software code compiled or downloaded to provide daemon, wallet CLI, and wallet RPC binaries.

[Dockerfiles](./dockerfiles/) are available for building images of your choice; `wownerod_nocompile` can be used for fetching pre-built binaries, the `wownerod_compile_*` are used for fully building and compiling the C++ software.

## Node-in-a-box

The simplest way to get started is to use `docker-compose` and turn up the provided services, including the Wownero daemon, monitoring tools, and a visualization/graphing tool.

```
docker-compose up -d
# wownerod available at ports 34567 and 34568
# prometheus available at port 9090
# exporter (/metrics) available at port 9000
# grafana available at port 3000
```

You can host the node on an official DNS endpoint for public usage or keep it local for your own private usage.

![](files/static/graf1.png)

![](files/static/graf2.png)

## Manual Daemon and Wallet Setup

The node and wallet software is in the same package, so both can be used from within the Docker container.

```
# build container image by fetching binaries
docker build -t wownero -f dockerfiles/wownerod_nocompile dockerfiles 

# or build container image by compiling from source (simple)
docker build -t wownero -f dockerfiles/wownerod_compile_simple dockerfiles 

# create network bridge so containers can communicate
docker network create --driver=bridge wownero

# run wownero daemon with RPC bindings
docker run -d --rm --name wownero-daemon \
  --net=wownero \
  -v daemon:/data \
  -p 34568:34568 \
   wownero \
   wownerod \
   --data-dir=/data \
   --rpc-bind-ip=0.0.0.0 \
   --confirm-external-bind \
   --non-interactive

# run wownero-wallet-cli
docker run --rm -it --name wownero-wallet \
  --net=wownero \
  -v wallet:/data \
  wownero \
  wownero-wallet-cli \
    --trusted-daemon \
    --daemon-address wownero-daemon:34568
```
